==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/BeforeScheduledActionPolicyRuleCondition.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.Duration;
import com.okta.sdk.resource.model.ScheduledUserLifecycleAction;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * BeforeScheduledActionPolicyRuleCondition
 */
@JsonPropertyOrder({ BeforeScheduledActionPolicyRuleCondition.JSON_PROPERTY_DURATION,
        BeforeScheduledActionPolicyRuleCondition.JSON_PROPERTY_LIFECYCLE_ACTION })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class BeforeScheduledActionPolicyRuleCondition implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_DURATION = "duration";
    private Duration duration;

    public static final String JSON_PROPERTY_LIFECYCLE_ACTION = "lifecycleAction";
    private ScheduledUserLifecycleAction lifecycleAction;

    public BeforeScheduledActionPolicyRuleCondition() {
    }

    public BeforeScheduledActionPolicyRuleCondition duration(Duration duration) {

        this.duration = duration;
        return this;
    }

    /**
     * Get duration
     *
     * @return duration
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DURATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Duration getDuration() {
        return duration;
    }

    @JsonProperty(JSON_PROPERTY_DURATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDuration(Duration duration) {
        this.duration = duration;
    }

    public BeforeScheduledActionPolicyRuleCondition lifecycleAction(ScheduledUserLifecycleAction lifecycleAction) {

        this.lifecycleAction = lifecycleAction;
        return this;
    }

    /**
     * Get lifecycleAction
     *
     * @return lifecycleAction
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LIFECYCLE_ACTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public ScheduledUserLifecycleAction getLifecycleAction() {
        return lifecycleAction;
    }

    @JsonProperty(JSON_PROPERTY_LIFECYCLE_ACTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLifecycleAction(ScheduledUserLifecycleAction lifecycleAction) {
        this.lifecycleAction = lifecycleAction;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        BeforeScheduledActionPolicyRuleCondition beforeScheduledActionPolicyRuleCondition = (BeforeScheduledActionPolicyRuleCondition) o;
        return Objects.equals(this.duration, beforeScheduledActionPolicyRuleCondition.duration)
                && Objects.equals(this.lifecycleAction, beforeScheduledActionPolicyRuleCondition.lifecycleAction);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(duration, lifecycleAction);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class BeforeScheduledActionPolicyRuleCondition {\n");
        sb.append("    duration: ").append(toIndentedString(duration)).append("\n");
        sb.append("    lifecycleAction: ").append(toIndentedString(lifecycleAction)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/BeforeScheduledActionPolicyRuleCondition.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.Duration;
import com.okta.sdk.resource.model.ScheduledUserLifecycleAction;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * BeforeScheduledActionPolicyRuleCondition
 */
@JsonPropertyOrder({ BeforeScheduledActionPolicyRuleCondition.JSON_PROPERTY_DURATION,
        BeforeScheduledActionPolicyRuleCondition.JSON_PROPERTY_LIFECYCLE_ACTION })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class BeforeScheduledActionPolicyRuleCondition implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_DURATION = "duration";
    private Duration duration;

    public static final String JSON_PROPERTY_LIFECYCLE_ACTION = "lifecycleAction";
    private ScheduledUserLifecycleAction lifecycleAction;

    public BeforeScheduledActionPolicyRuleCondition() {
    }

    public BeforeScheduledActionPolicyRuleCondition duration(Duration duration) {

        this.duration = duration;
        return this;
    }

    /**
     * Get duration
     *
     * @return duration
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DURATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Duration getDuration() {
        return duration;
    }

    @JsonProperty(JSON_PROPERTY_DURATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDuration(Duration duration) {
        this.duration = duration;
    }

    public BeforeScheduledActionPolicyRuleCondition lifecycleAction(ScheduledUserLifecycleAction lifecycleAction) {

        this.lifecycleAction = lifecycleAction;
        return this;
    }

    /**
     * Get lifecycleAction
     *
     * @return lifecycleAction
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LIFECYCLE_ACTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public ScheduledUserLifecycleAction getLifecycleAction() {
        return lifecycleAction;
    }

    @JsonProperty(JSON_PROPERTY_LIFECYCLE_ACTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLifecycleAction(ScheduledUserLifecycleAction lifecycleAction) {
        this.lifecycleAction = lifecycleAction;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        BeforeScheduledActionPolicyRuleCondition beforeScheduledActionPolicyRuleCondition = (BeforeScheduledActionPolicyRuleCondition) o;
        return Objects.equals(this.duration, beforeScheduledActionPolicyRuleCondition.duration)
                && Objects.equals(this.lifecycleAction, beforeScheduledActionPolicyRuleCondition.lifecycleAction);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(duration, lifecycleAction);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class BeforeScheduledActionPolicyRuleCondition {\n");
        sb.append("    duration: ").append(toIndentedString(duration)).append("\n");
        sb.append("    lifecycleAction: ").append(toIndentedString(lifecycleAction)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
